Credits
=========

Primary:
--------
- `Iheanyi Ekechukwu <https://github.com/iheanyi>`_ (Creator)
- `Anthony Forsberg <https://github.com/Evolution0>`_ (Maintainer)
- `Contributors Graph <https://github.com/iheanyi/bandcamp-dl/graphs/contributors>`_


Third-party:
------------
- `AUR Package (bandcamp-dl-git) <https://aur.archlinux.org/packages/bandcamp-dl-git>`_
- `Homebrew Formulae (bandcamp-dl) <https://formulae.brew.sh/formula/bandcamp-dl>`_
